# ListLabelledObjectsResponse

Response object for listing LabelledObjects

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**labelled_objects** | [**[LabelledObject]**](LabelledObject.md) | The matching LabelledObjects | 
**limit** | **int** | limit of LabelledObjects in the response | 
**page_at_id** | **str** | the id to request in the pagination query to get the next page | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


